#ifndef NT2_INCLUDE_FUNCTIONS_ACOSPI_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACOSPI_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/acospi.hpp>

#endif
